@@ -1,4 +1,39 @@
 from collections import defaultdict
+import string
+import re
+from collections import Counter
+
+
+def _normalize_answer(s):
+    """Lower text and remove punctuation, articles and extra whitespace."""
+
+    def remove_articles(text):
+        return re.sub(r'\b(a|an|the)\b', ' ', text)
+
+    def white_space_fix(text):
+        return ' '.join(text.split())
+
+    def remove_punc(text):
+        exclude = set(string.punctuation)
+        return ''.join(ch for ch in text if ch not in exclude)
+
+    def lower(text):
+        return text.lower()
+
+    return white_space_fix(remove_articles(remove_punc(lower(s))))
+
+
+def _f1_score(prediction, ground_truth):
+    prediction_tokens = _normalize_answer(prediction).split()
+    ground_truth_tokens = _normalize_answer(ground_truth).split()
+    common = Counter(prediction_tokens) & Counter(ground_truth_tokens)
+    num_same = sum(common.values())
+    if num_same == 0:
+        return 0
+    precision = 1.0 * num_same / len(prediction_tokens)
+    recall = 1.0 * num_same / len(ground_truth_tokens)
+    f1 = (2 * precision * recall) / (precision + recall)
+    return f1
 
 
 class EvalMetric:
@@ -32,18 +67,20 @@ class EvalMetric:
     def cal_score(self, metric):
         for name, task in self.tasks.items():
             print("Task : " + name + " report ")
-            if "em" in metric:
+            if "emf1" in metric:
                 em = 0
                 total = 0
+                f1 = 0
                 for pos, predict in enumerate(task['predicted']):
                     target = task['target'][pos]
                     equal = False
-                    if not isinstance(predict, list) and predict.replace("[SEP]", "").replace(" ", "") == target.replace("[SEP]", "").replace(" ",
-                                                                                                            ""):
+                    if _normalize_answer(predict) == _normalize_answer(target):
                         equal = True
-                    em += 1 if equal else 0
+                    f1 += _f1_score(predict, target)
+                    if equal:
+                        em += 1
                     total += 1
-                result = em / total
+                result = {"EM": em / total, "F1": f1 / total}
             if "nlg" in metric:
                 try:
                     from nlgeval import NLGEval
